@@ -24,11 +24,11 @@ class InitOralProcessRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param SessionId: 语音段唯一标识，一段完整语音使用一个SessionId，不同语音段的评测需要使用不同的SessionId。一般使用uuid(通用唯一识别码)来作为它的值，要尽量保证SessionId的唯一性。
         :type SessionId: str
         :param RefText: 被评估语音对应的文本，仅支持中文和英文。
-句子模式下不超过个 30 单词或者中文文字，段落模式不超过 120 单词或者中文文字，中文评估使用 utf-8 编码，自由说模式该值无效。
+句子模式下不超过个 30 单词或者中文文字，段落模式不超过 120 单词或者中文文字，中文评估使用 utf-8 编码，自由说模式RefText可以不填。
 关于RefText的文本键入要求，请参考[评测模式介绍](https://cloud.tencent.com/document/product/884/56131)。
 如需要在评测模式下使用自定义注音（支持中英文），可以通过设置「TextMode」参数实现，设置方式请参考[音素标注](https://cloud.tencent.com/document/product/884/33698)。
         :type RefText: str
@@ -72,6 +72,7 @@ class InitOralProcessRequest(AbstractModel):
         :param ServerType: 评估语言
 0：英文
 1：中文
+ServerType不填默认为0
         :type ServerType: int
         :param IsAsync: 异步模式标识
 0：同步模式
@@ -126,7 +127,7 @@ class InitOralProcessResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param SessionId: 语音段唯一标识，一个完整语音一个SessionId
         :type SessionId: str
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -147,14 +148,15 @@ class Keyword(AbstractModel):
     """
 
     def __init__(self):
-        """
-        :param RefText: 被评估语音对应的文本，句子模式下不超过个 20 单词或者中文文字，段落模式不超过 120 单词或者中文文字，中文评估使用 utf-8 编码，自由说模式该值无效。如需要在单词模式和句子模式下使用自定义音素，可以通过设置 TextMode 使用[音素标注](https://cloud.tencent.com/document/product/884/33698)。
+        r"""
+        :param RefText: 被评估语音对应的文本，句子模式下不超过个 20 单词或者中文文字，段落模式不超过 120 单词或者中文文字，中文评估使用 utf-8 编码，自由说模式RefText可以不填。如需要在单词模式和句子模式下使用自定义音素，可以通过设置 TextMode 使用[音素标注](https://cloud.tencent.com/document/product/884/33698)。
         :type RefText: str
         :param EvalMode: 评估模式，0：词模式（中文评测模式下为文字模式），1：句子模式，2：段落模式，3：自由说模式，当为词模式评估时，能够提供每个音节的评估信息，当为句子模式时，能够提供完整度和流利度信息。
         :type EvalMode: int
         :param ScoreCoeff: 评价苛刻指数，取值为[1.0 - 4.0]范围内的浮点数，用于平滑不同年龄段的分数，1.0为小年龄段，4.0为最高年龄段
         :type ScoreCoeff: float
         :param ServerType: 评估语言，0：英文，1：中文。
+ServerType不填默认传0
         :type ServerType: int
         :param TextMode: 输入文本模式，0: 普通文本，1：[音素结构](https://cloud.tencent.com/document/product/884/33698)文本。
         :type TextMode: int
@@ -187,7 +189,7 @@ class KeywordEvaluateRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param SeqId: 流式数据包的序号，从1开始，当IsEnd字段为1后后续序号无意义，当IsLongLifeSession不为1且为非流式模式时无意义。
 注意：序号上限为3000，不能超过上限。
         :type SeqId: int
@@ -255,7 +257,7 @@ class KeywordEvaluateResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param KeywordScores: 关键词得分
         :type KeywordScores: list of KeywordScore
         :param SessionId: 语音段唯一标识，一段完整语音使用一个SessionId，不同语音段的评测需要使用不同的SessionId。一般使用uuid(通用唯一识别码)来作为它的值，要尽量保证SessionId的唯一性。
@@ -285,7 +287,7 @@ class KeywordScore(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Keyword: 关键词
         :type Keyword: str
         :param PronAccuracy: 发音精准度，取值范围[-1, 100]，当取-1时指完全不匹配，当为句子模式时，是所有已识别单词准确度的加权平均值，在reftext中但未识别出来的词不计入分数中。当为流式模式且请求中IsEnd未置1时，取值无意义。
@@ -335,7 +337,7 @@ class PhoneInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param MemBeginTime: 当前音节语音起始时间点，单位为ms
         :type MemBeginTime: int
         :param MemEndTime: 当前音节语音终止时间点，单位为ms
@@ -391,7 +393,7 @@ class SentenceInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param SentenceId: 句子序号，在段落、自由说模式下有效，表示断句序号，最后的综合结果的为-1.
         :type SentenceId: int
         :param Words: 详细发音评估结果
@@ -440,7 +442,7 @@ class TransmitOralProcessRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param SeqId: 流式数据包的序号，从1开始，当IsEnd字段为1后后续序号无意义，当IsLongLifeSession不为1且为非流式模式时无意义。
 注意：序号上限为3000，不能超过上限。
         :type SeqId: int
@@ -503,7 +505,7 @@ class TransmitOralProcessResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param PronAccuracy: 发音精准度，取值范围[-1, 100]，当取-1时指完全不匹配，当为句子模式时，是所有已识别单词准确度的加权平均值，在reftext中但未识别出来的词不计入分数中。当为流式模式且请求中IsEnd未置1时，取值无意义。
         :type PronAccuracy: float
         :param PronFluency: 发音流利度，取值范围[0, 1]，当为词模式时，取值无意义；当为流式模式且请求中IsEnd未置1时，取值无意义
@@ -566,7 +568,7 @@ class TransmitOralProcessWithInitRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param SeqId: 流式数据包的序号，从1开始，当IsEnd字段为1后后续序号无意义，当IsLongLifeSession不为1且为非流式模式时无意义。
 注意：序号上限为3000，不能超过上限。
         :type SeqId: int
@@ -587,7 +589,7 @@ class TransmitOralProcessWithInitRequest(AbstractModel):
         :param SessionId: 语音段唯一标识，一段完整语音使用一个SessionId，不同语音段的评测需要使用不同的SessionId。一般使用uuid(通用唯一识别码)来作为它的值，要尽量保证SessionId的唯一性。
         :type SessionId: str
         :param RefText: 被评估语音对应的文本，仅支持中文和英文。
-句子模式下不超过个 30 单词或者中文文字，段落模式不超过 120 单词或者中文文字，中文评估使用 utf-8 编码，自由说模式该值无效。
+句子模式下不超过个 30 单词或者中文文字，段落模式不超过 120 单词或者中文文字，中文评估使用 utf-8 编码，自由说模式RefText可以不填。
 关于RefText的文本键入要求，请参考[评测模式介绍](https://cloud.tencent.com/document/product/884/56131)。
 如需要在评测模式下使用自定义注音（支持中英文），可以通过设置「TextMode」参数实现，设置方式请参考[音素标注](https://cloud.tencent.com/document/product/884/33698)。
         :type RefText: str
@@ -629,6 +631,7 @@ class TransmitOralProcessWithInitRequest(AbstractModel):
         :param ServerType: 评估语言
 0：英文
 1：中文
+ServerType不填默认为0
         :type ServerType: int
         :param IsAsync: 异步模式标识
 0：同步模式
@@ -695,7 +698,7 @@ class TransmitOralProcessWithInitResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param PronAccuracy: 发音精准度，取值范围[-1, 100]，当取-1时指完全不匹配，当为句子模式时，是所有已识别单词准确度的加权平均值，在reftext中但未识别出来的词不计入分数中。当为流式模式且请求中IsEnd未置1时，取值无意义。
         :type PronAccuracy: float
         :param PronFluency: 发音流利度，取值范围[0, 1]，当为词模式时，取值无意义；当为流式模式且请求中IsEnd未置1时，取值无意义
@@ -758,7 +761,7 @@ class WordRsp(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param MemBeginTime: 当前单词语音起始时间点，单位为ms，该字段段落模式下无意义。
         :type MemBeginTime: int
         :param MemEndTime: 当前单词语音终止时间点，单位为ms，该字段段落模式下无意义。
